'use strict';

var culori = require('culori');

function convertColorSpace(rgb, targetSpace) {
    const alphaUsed = rgb.alpha !== 1;
    const alphaToken = alphaUsed ? `/${rgb.alpha}` : '';
    if (rgb.r === 0 && rgb.g === 0 && rgb.b === 0) return 'black' + alphaToken;
    if (rgb.r === 1 && rgb.g === 1 && rgb.b === 1) return 'white' + alphaToken;
    switch(targetSpace){
        case 'hex':
            return alphaUsed ? culori.serializeHex8(rgb) : culori.serializeHex(rgb);
        case 'rgba':
        case 'rgb':
            return `rgb(${Math.round(rgb.r * 255)}|${Math.round(rgb.g * 255)}|${Math.round(rgb.b * 255)}${alphaToken})`;
        case 'hsla':
        case 'hsl':
            const hsl = culori.modeHsl.fromMode.rgb(rgb);
            return `hsl(${Math.round(hsl.h || 0)}|${Math.round(hsl.s * 100)}%|${Math.round(hsl.l * 100)}%${alphaToken})`;
        case 'hwb':
            const hwb = culori.modeHwb.fromMode.rgb(rgb);
            return `hwb(${Math.round(hwb.h || 0)}|${Math.round(hwb.w * 100)}%|${Math.round(hwb.b * 100)}%${alphaToken})`;
        case 'lab':
            const lab = culori.modeLab.fromMode.rgb(rgb);
            return `lab(${Math.round(lab.l)}%|${Math.round(lab.a)}|${Math.round(lab.b || 0)}${alphaToken})`;
        case 'lch':
            const lch = culori.modeLch.fromMode.rgb(rgb);
            return `lch(${Math.round(lch.l)}%|${Math.round(lch.c)}|${Math.round(lch.h || 0)}${alphaToken})`;
        case 'oklab':
            const oklab = culori.modeOklab.fromMode.rgb(rgb);
            return `oklab(${Math.round(oklab.l * 100)}%|${oklab.a.toFixed(4)}|${oklab.b.toFixed(4)}${alphaToken})`;
        case 'oklch':
            const oklch = culori.modeOklch.fromMode.rgb(rgb);
            return `oklch(${Math.round(oklch.l * 100)}%|${oklch.c.toFixed(4)}|${Math.round(oklch.h || 0)}${alphaToken})`;
    }
    // color()
    return culori.formatCss(rgb).replace(' / ', '/').replace(' ', '|');
}

module.exports = convertColorSpace;
